Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(46)

Unified Diff: src/bootstrapper.cc

Issue 113121: Changed the flags that indicate the status of running vs dead... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/bootstrapper.cc
===================================================================
--- src/bootstrapper.cc (revision 1900)
+++ src/bootstrapper.cc (working copy)
@@ -1509,8 +1509,8 @@
current_ = this;
result_ = NULL;
- // If V8 hasn't been and cannot be initialized, just return.
- if (!V8::HasBeenSetup() && !V8::Initialize(NULL)) return;
+ // If V8 isn't running and cannot be initialized, just return.
+ if (!V8::IsRunning() && !V8::Initialize(NULL)) return;
// Before creating the roots we must save the context and restore it
// on all function exits.

Powered by Google App Engine
This is Rietveld 408576698